var ASSERT;

ASSERT = require('assert');

exports.TestContext = (function() {

  function TestContext() {
    this.assertionCount = 0;
  }

  TestContext.prototype.expectCount = function(n) {
    this.expectedAssertions = n;
  };

  TestContext.prototype.checkCount = function() {
    var actual, expected, msg;
    actual = this.assertionCount;
    expected = this.expectedAssertions;
    if (typeof expected === 'number') {
      msg = "expected " + expected + " assertions but got " + actual;
      return ASSERT.equal(actual, expected, msg);
    }
  };

  TestContext.prototype.assert = function(val, msg) {
    this.assertionCount += 1;
    return ASSERT(val, msg);
  };

  TestContext.prototype.equal = function(actual, expected, msg) {
    this.assertionCount += 1;
    return ASSERT.equal(actual, expected, msg);
  };

  TestContext.prototype.notEqual = function(actual, expected, msg) {
    this.assertionCount += 1;
    return ASSERT.notEqual(actual, expected, msg);
  };

  TestContext.prototype.strictEqual = function(actual, expected, msg) {
    this.assertionCount += 1;
    return ASSERT.strictEqual(actual, expected, msg);
  };

  TestContext.prototype.notStrictEqual = function(actual, expected, msg) {
    this.assertionCount += 1;
    return ASSERT.notStrictEqual(actual, expected, msg);
  };

  TestContext.prototype.deepEqual = function(actual, expected, msg) {
    this.assertionCount += 1;
    return ASSERT.deepEqual(actual, expected, msg);
  };

  TestContext.prototype.notDeepEqual = function(actual, expected, msg) {
    this.assertionCount += 1;
    return ASSERT.notDeepEqual(actual, expected, msg);
  };

  TestContext.prototype.throws = function(block, err, msg) {
    this.assertionCount += 1;
    return ASSERT.throws(block, err, msg);
  };

  TestContext.prototype.doesNotThrow = function(block, err, msg) {
    this.assertionCount += 1;
    return ASSERT.doesNotThrow(block, err, msg);
  };

  return TestContext;

})();

exports.test = function(fn) {
  var test;
  test = function(done) {
    var context, whenDone;
    context = new exports.TestContext();
    whenDone = function(err) {
      if (err) {
        return done(err);
      }
      context.checkCount();
      return done();
    };
    return fn.call(context, whenDone);
  };
  return test;
};

exports._ = exports.underscore = require('underscore');
